@@ -1,3 +1,7 @@
+"""LookAt class information
+"""
+
+
 class LookAt():
     """LookAt class information
 
@@ -6,7 +10,6 @@ class LookAt():
         point: {Vector3f} -- point to look at coordinate
         up: {Vector3f} -- up vector
     """
-
     def __init__(self, eye, point, up):
         """LookAt information storage
         
